import { withQuery } from "ufo";
import { useRegistryScript } from "#nuxt-scripts/utils";
import { object, string, optional } from "#nuxt-scripts-validator";
export const GoogleTagManagerOptions = object({
  id: string(),
  l: optional(string())
});
export function useScriptGoogleTagManager(_options) {
  return useRegistryScript(_options?.key || "googleTagManager", (options) => ({
    scriptInput: {
      src: withQuery("https://www.googletagmanager.com/gtm.js", { id: options?.id, l: options?.l })
    },
    schema: import.meta.dev ? GoogleTagManagerOptions : void 0,
    scriptOptions: {
      use: () => {
        return { dataLayer: window[options.l ?? "dataLayer"], google_tag_manager: window.google_tag_manager };
      },
      performanceMarkFeature: "nuxt-third-parties-gtm",
      tagPriority: 1
    },
    clientInit: import.meta.server ? void 0 : () => {
      const dataLayerName = options?.l ?? "dataLayer";
      window[dataLayerName] = window[options?.l ?? "dataLayer"] || [];
      function gtag() {
        window[dataLayerName].push(arguments);
      }
      _options?.onBeforeGtmStart?.(gtag);
      window[dataLayerName].push({ "gtm.start": (/* @__PURE__ */ new Date()).getTime(), "event": "gtm.js" });
    }
  }), _options);
}
